
//
// TakeOver.c - 18-Sep-96 v1.01 AFD
//

#include <stdio.h>
#include <ctype.h>
#include <stdlib.h>
#include <string.h>

#include "phostpdk.h"

extern int getch( void );

int main( int argc, char *argv[] )
	{
	char *psName    = "TakeOver",
		  *psVersion = "v1.01",
		  *psDate    = "18-Sep-96";
	char	sPlanName[PLANETNAME_SIZE+1],
			sShipName[SHIPNAME_SIZE+1],
			sRaceName[LONGNAME_SIZE+1];
	Int16 nVic,		//	Victor
			nVan,		// Vanquished
			nPlan,
			nShip,
			nDummy1 = 0,
			nDummy2 = 0;

	if ( argc == 4 ) {
		nVic = atoi( argv[2] );
		nVan = atoi( argv[3] );
		gGameDirectory = argv[1];

		if ( ( nVic < 1 ) || ( nVic > 11 ) ) {
			fprintf( stderr, "%s Invalid Victor (%d)\n", psName, nVic );
			getch();
			exit(1);

		} else if ( ( nVan < 1 ) || ( nVan > 11 ) ) {
			fprintf( stderr, "%s Invalid Vanquished (%d)\n", psName, nVan );
			getch();
			exit(1);

		} else if ( nVic == nVan ) {
			fprintf( stderr, "%s Victor == Vanquished !! (%d == %d)\n",
				psName, nVic, nVan );
			getch();
			exit(1);
		}
	} else {
		fprintf( stderr, "%s: %s %s AFD\n", psName, psVersion, psDate );
		fprintf( stderr, "Usage: %s <GameDirectory> <Victor (1-11)> <Vanquished (1-11)>\n", psName );
		exit(1);
	}

	// Initialize the PDK

	InitPHOSTLib();

	if (! Read_Planets_File(&nDummy1)) {
		printf( "%s: Unable to read Planets Files\n", psName );
		getch();
		exit(1);
	}

	// We only need to read in a subset of the game files
	if (! Read_Bases_File(&nDummy1, &nDummy2)) {
		fprintf( stderr, "%s: Unable to read Base Files\n", psName );
		getch();
		exit(1);
	}

	if (! Read_Ships_File( &nDummy1) ) {
		fprintf( stderr, "%s: Unable to read Ships Files\n", psName );
		getch();
		exit(1);
	}

	if (! Read_Planetname_File()) {
		fprintf( stderr, "%s: Unable to read Planets Name Files\n", psName );
		getch();
		exit(1);
	}

	if (! Read_Racenames_File()) {
		fprintf( stderr, "%s: Unable to read Race Name Files\n", psName );
		getch();
		exit(1);
	}

	printf( "%s: %s %s AFD\n\n", psName, psVersion, psDate );
	printf( "GameDirectory = %s\n", gGameDirectory );
	printf( "Victor        = %s\n", RaceLongName( nVic, sRaceName ) );
	printf( "Vanquished    = %s\n\n", RaceLongName( nVan, sRaceName ) );
	printf( "Hit anykey to run TakeOver\n\n" );

	getch();

	printf( "Checking Planets...\n" );

	for ( nPlan = 1; nPlan <= PLANET_NR; nPlan++ ) {
		if ( IsPlanetExist( nPlan ) ) {
			if ( PlanetOwner( nPlan ) == nVan ) {
				printf( "%3d: %s ", nPlan, PlanetName( nPlan, sPlanName ) );
				PutPlanetOwner( nPlan, nVic );

				if ( IsBaseExist( nPlan ) && ( BaseOwner( nPlan ) == nVan ) ) {
					printf( "StarBase" );
					PutBaseOwner( nPlan, nVic );
				}

				printf( "\n" );
			}
		}
	}

	printf( "\nChecking Ships...\n" );

	for ( nShip = 1; nShip <= SHIP_NR; nShip++ ) {
		if ( IsShipExist( nShip ) ) {
			if ( ShipOwner( nShip ) == nVan ) {
				printf( "%3d: %s\n", nShip, ShipName( nShip, sShipName ) );
				PutShipOwner( nShip, nVic );
			}
		}
	}

	printf( "\nWriting Files...\n" );

	// Close down. We need to write the files back to disk.

	if (! Write_Planets_File(nDummy1)) {
		fprintf( stderr, "%s: Error Writing Planets files\n", psName );
		getch();
		exit(1);
	}

	if (! Write_Bases_File(nDummy1, nDummy2)) {
		fprintf( stderr, "%s: Error Writing Bases files\n", psName );
		getch();
		exit(1);
	}

	if (! Write_Ships_File(nDummy1)) {
		fprintf( stderr, "%s: Error Writing Ships files\n", psName );
		getch();
		exit(1);
	}

	FreePHOSTLib();

	printf( "\n%s complete\n", psName );
	getch();

	return 0;
}

